@@ -35,7 +35,10 @@ class OpenStackBase(object):
             _tty_out=False,
             _out=lambda x: log.info(x.strip()),
             _err=lambda x: log.info(x.strip()),
-            _env={'OS_CLIENT_CONFIG_FILE': self.config_file},
+            _env={
+                'OS_CLIENT_CONFIG_FILE': self.config_file,
+                'PATH': os.getenv('PATH'),
+            },
         )
 
 
