@@ -110,7 +110,8 @@ class Service(object):
 
     def create_or_update(self):
         self.ensure_non_empty_service_group()
-        hosts = self.service2hosts[self.args['name']]
+        service = self.args['name']
+        hosts = self.service2hosts[service]
         self.create_missings(hosts)
         self.maybe_delegate_dns()
         playbook = ansible_utils.Playbook(self.config_dir, self.share_dir)
@@ -120,9 +121,11 @@ class Service(object):
             playbook_file = f'{self.config_dir}/{self.args["playbook"]}'
             if not os.path.exists(playbook_file):
                 playbook_file = f'{self.share_dir}/{self.args["playbook"]}'
+
+        subset = f"{service}-service-group:{service}-client-group:&live"
         playbook.run([
             f'--private-key={self.dotenough.private_key()}',
-            '--limit', ','.join(hosts + ['localhost']),
+            '--limit', subset,
             playbook_file,
         ])
         return {'fqdn': f'{self.args["name"]}.{self.args["domain"]}'}
