@@ -2,8 +2,7 @@ import logging
 
 from cliff.command import Command
 from enough import settings
-from enough.common.openstack import OpenStack
-from enough.common import dotenough
+from enough.common import Enough
 from enough.common import options
 
 
@@ -21,10 +20,8 @@ class Create(Command):
     def take_action(self, parsed_args):
         args = vars(self.app.options)
         args.update(vars(parsed_args))
-        d = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, args['domain'])
-        d.ensure()
-        o = OpenStack(settings.CONFIG_DIR, **args)
-        o.backup_create(args['volumes'])
+        e = Enough(settings.CONFIG_DIR, settings.SHARE_DIR, **args)
+        e.backup_create()
 
 
 class Prune(Command):
@@ -41,8 +38,5 @@ class Prune(Command):
     def take_action(self, parsed_args):
         args = vars(self.app.options)
         args.update(vars(parsed_args))
-        d = dotenough.DotEnoughOpenStack(settings.CONFIG_DIR, args['domain'])
-        d.ensure()
-        o = OpenStack(settings.CONFIG_DIR, **args)
-        o.backup_prune(args['days'])
-        o.volume_prune(args['days'])
+        e = Enough(settings.CONFIG_DIR, settings.SHARE_DIR, **args)
+        e.backup_prune()
