@@ -169,7 +169,7 @@ def test_delegate_dns(request, pytestconfig, host):
     url = f"https://api.{domain}"
     s = requests.Session()
     data = {
-        "name": f"bar",
+        "name": "bar",
         "ip": "5.6.7.8",
     }
     r = s.post(f'{url}/delegate-dns/', json=data, timeout=60, verify=certs)
