@@ -8,8 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'forum-host')
-        assert r['attrs']['name'] == 'forum-host'
+        assert 'forum-host' in self.get_hosts(host='forum-host')
 
     def test_service(self, host):
         assert self.is_service_ok('forum-host!Forum')
