@@ -1,4 +1,7 @@
+import logging
+
 testinfra_hosts = ['ansible://infrastructure1-host']
+logger = logging.getLogger(__name__)
 
 
 def test_encrypted_volume(host):
@@ -9,6 +12,6 @@ def test_encrypted_volume(host):
     test ! -e /srv/docker
     test ! -e /srv/snap
     """)
-    print(cmd.stdout)
-    print(cmd.stderr)
+    logger.debug('stdout %s', cmd.stdout)
+    logger.debug('stderr %s', cmd.stderr)
     assert 0 == cmd.rc
