@@ -8,8 +8,7 @@ IcingaHelper.icinga_host = 'bind-host'
 class TestChecks(IcingaHelper):
 
     def test_host(self):
-        r = self.get_client().objects.get('Host', 'weblate-host')
-        assert r['attrs']['name'] == 'weblate-host'
+        assert 'weblate-host' in self.get_hosts(host='weblate-host')
 
     def test_service(self, host):
         assert self.is_service_ok('weblate-host!Weblate')
