@@ -16,3 +16,6 @@ class TestChecks(IcingaHelper):
         website.update(testinfra.get_host('ansible://website-host',
                                           ansible_inventory=self.inventory))
         assert self.is_service_ok('website-host!Website')
+
+    def test_proxy_host(self):
+        assert 'proxy-host' in self.get_hosts(host='proxy-host')
