@@ -130,7 +130,7 @@ def test_playbook_environment(monkeypatch):
     monkeypatch.setenv('ANSIBLE_VERBOSITY', '2')
     # default value of role default variable 'gitlab_runner__token' is the
     # 'GITLAB_RUNNER_TOKEN' environment variable (using 'env' lookup)
-    value = playbook.get_role_variable('debops.gitlab_runner', 'gitlab_runner__token',
+    value = playbook.get_role_variable('gitlab_runner', 'gitlab_runner__token',
                                        'gitlab-host')
     assert 'test_value' == value
 
