@@ -72,9 +72,6 @@ function build_image() {
     (
         cat enough/common/data/base.dockerfile
         cat tests/tox.dockerfile
-        if test "$GITLAB_CI" ; then
-            cat tests/copy-to-opt.dockerfile
-        fi
     ) | timeout $max_execution_time docker build \
 		--build-arg=USER_ID="$(id -u)" \
 		--build-arg=DOCKER_GID="$(getent group docker | cut -d: -f3)" \
@@ -95,9 +92,11 @@ function run_tests() {
 
     find $d \( -name '*.pyc' -o -name '*.pyo' -o -name __pycache__ \) -delete
     if test "$GITLAB_CI" ; then
-        args="--workdir /opt"
+        gitlab_container=$(basename $(cat /proc/1/cpuset))  # current container ID
+        args="--workdir ${CI_PROJECT_DIR} -e CI_PROJECT_DIR=${CI_PROJECT_DIR} --volumes-from ${gitlab_container}"
         : ${PYTEST_ADDOPTS=-m \"not openstack_integration and not libvirt_integration\"}
         PASS_GITLAB_CI="-e GITLAB_CI=${GITLAB_CI}"
+        chmod -R o= ${CI_PROJECT_DIR}
     else
         args="--volume ${d}:${d} --workdir ${d} --volume $HOME/.enough:$HOME/.enough --volume $HOME/.ansible:$HOME/.ansible -e HOME=$HOME"
         # handle git worktree
